<?php
/**
 * Default theme options.
 *
 * @package Restaurantz
 */

if ( ! function_exists( 'restaurantz_get_default_theme_options' ) ) :

	/**
	 * Get default theme options
	 *
	 * @since 1.0.0
	 *
	 * @return array Default theme options.
	 */
	function restaurantz_get_default_theme_options() {

		$defaults = array();

		// Header.
		$defaults['show_title']                 = true;
		$defaults['show_tagline']               = true;
		$defaults['enable_sticky_primary_menu'] = false;

		// Search.
		$defaults['search_placeholder'] = esc_html__( 'Search...', 'restaurantz' );

		// Layout.
		$defaults['global_layout']           = 'right-sidebar';
		$defaults['archive_layout']          = 'excerpt';
		$defaults['archive_image']           = 'large';
		$defaults['archive_image_alignment'] = 'center';
		$defaults['single_image']            = 'large';
		$defaults['single_image_alignment']  = 'center';

		// Pagination.
		$defaults['pagination_type'] = 'default';

		// Content Meta.
		$defaults['show_meta_date']       = true;
		$defaults['show_meta_author']     = true;
		$defaults['show_meta_categories'] = true;
		$defaults['show_meta_tags']       = true;
		$defaults['show_meta_comment']    = true;

		// Footer.
		$defaults['footer_background_image'] = '';
		$defaults['copyright_text']       = esc_html__( 'Copyright &copy; [the-year] [the-site-link]. All rights reserved.', 'restaurantz' );
		$defaults['powered_by_text']      = esc_html__( 'Restaurantz Pro by ', 'restaurantz' ) . '<a target="_blank" rel="designer" href="http://wenthemes.com/">WEN Themes</a>';
		$defaults['reset_footer_content'] = false;
		$defaults['go_to_top']            = true;


		// Blog.
		$defaults['excerpt_length'] = 40;
		$defaults['read_more_text'] = esc_html__( 'Read More ...', 'restaurantz' );

		// Author Bio.
		$defaults['author_bio_in_single']           = true;
		$defaults['author_bio_show_recent_posts']   = false;
		$defaults['author_bio_recent_posts_number'] = 3;

		// Breadcrumb.
		$defaults['breadcrumb_type'] = 'simple';

		// Advanced.
		$defaults['custom_css'] = '';

		// Font.
		$font_keys = restaurantz_get_font_family_theme_settings_options();
		if ( ! empty( $font_keys ) ) {
			foreach ( $font_keys as $k => $v ) {
			  $defaults[ $k ]  = $v['default'];
			}
		}
		$defaults['reset_font_settings'] = false;

		// Color.
		$colors = restaurantz_get_default_colors();
		if ( ! empty( $colors ) ) {
		  foreach ( $colors as $key => $val ) {
		    $defaults[ $key ] = $val;
		  }
		}

		// Pass through filter.
		$defaults = apply_filters( 'restaurantz_filter_default_theme_options', $defaults );

		return $defaults;

	}

endif;
